summaryrefslogtreecommitdiffstats
path: root/kexi/3rdparty/kexisql3/src/pragma.c
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/3rdparty/kexisql3/src/pragma.c')
-rw-r--r--kexi/3rdparty/kexisql3/src/pragma.c16
1 files changed, 8 insertions, 8 deletions
diff --git a/kexi/3rdparty/kexisql3/src/pragma.c b/kexi/3rdparty/kexisql3/src/pragma.c
index c85c19d5..618ce9e1 100644
--- a/kexi/3rdparty/kexisql3/src/pragma.c
+++ b/kexi/3rdparty/kexisql3/src/pragma.c
@@ -86,7 +86,7 @@ static int getTempStore(const char *z){
** Invalidate temp storage, either when the temp storage is changed
** from default, or when 'file' and the temp_store_directory has changed
*/
-static int invalidateTempStorage(Parse *pParse){
+static int tqinvalidateTempStorage(Parse *pParse){
sqlite3 *db = pParse->db;
if( db->aDb[1].pBt!=0 ){
if( db->flags & SQLITE_InTrans ){
@@ -112,7 +112,7 @@ static int changeTempStorage(Parse *pParse, const char *zStorageType){
int ts = getTempStore(zStorageType);
sqlite3 *db = pParse->db;
if( db->temp_store==ts ) return SQLITE_OK;
- if( invalidateTempStorage( pParse ) != SQLITE_OK ){
+ if( tqinvalidateTempStorage( pParse ) != SQLITE_OK ){
return SQLITE_ERROR;
}
db->temp_store = ts;
@@ -142,7 +142,7 @@ static void returnSingleInt(Parse *pParse, const char *zLabel, int value){
static int flagPragma(Parse *pParse, const char *zLeft, const char *zRight){
static const struct sPragmaType {
const char *zName; /* Name of the pragma */
- int mask; /* Mask for the db->flags value */
+ int tqmask; /* Mask for the db->flags value */
} aPragma[] = {
{ "vdbe_trace", SQLITE_VdbeTrace },
{ "sql_trace", SQLITE_SqlTrace },
@@ -164,12 +164,12 @@ static int flagPragma(Parse *pParse, const char *zLeft, const char *zRight){
v = sqlite3GetVdbe(pParse);
if( v ){
if( zRight==0 ){
- returnSingleInt(pParse, p->zName, (db->flags & p->mask)!=0 );
+ returnSingleInt(pParse, p->zName, (db->flags & p->tqmask)!=0 );
}else{
if( getBoolean(zRight) ){
- db->flags |= p->mask;
+ db->flags |= p->tqmask;
}else{
- db->flags &= ~p->mask;
+ db->flags &= ~p->tqmask;
}
}
/* If one of these pragmas is executed, any prepared statements
@@ -377,7 +377,7 @@ void sqlite3Pragma(
** Return or set the local value of the temp_store_directory flag. Changing
** the value sets a specific directory to be used for temporary files.
** Setting to a null string reverts to the default temporary directory search.
** If temporary directory is changed, then invalidateTempStorage.
**
*/
if( sqlite3StrICmp(zLeft, "temp_store_directory")==0 ){
@@ -397,7 +397,7 @@ void sqlite3Pragma(
|| (TEMP_STORE==1 && db->temp_store<=1)
|| (TEMP_STORE==2 && db->temp_store==1)
){
- invalidateTempStorage(pParse);
+ tqinvalidateTempStorage(pParse);
}
sqliteFree(sqlite3_temp_directory);
if( zRight[0] ){
@@ -377,7 +377,7 @@ void sqlite3Pragma(
** the value sets a specific directory to be used for temporary files.
** Setting to a null string reverts to the default temporary directory search.
- ** If temporary directory is changed, then invalidateTempStorage.
+ ** If temporary directory is changed, then tqinvalidateTempStorage.
**
*/